#import "IceTeaStudioPluginsPlugin.h"
#import "UIView+Toast.h"

@implementation IceTeaStudioPluginsPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"ice_tea_studio_plugins"
            binaryMessenger:[registrar messenger]];
  IceTeaStudioPluginsPlugin* instance = [[IceTeaStudioPluginsPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"getPlatformVersion" isEqualToString:call.method]) {
    result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  } else if ([@"showToast" isEqualToString:call.method]) {
      NSString *msg = call.arguments[@"msg"];
      NSString *gravity = call.arguments[@"gravity"];
      NSString *bgColor = call.arguments[@"backgroundColor"];
      NSString *titleColor = call.arguments[@"textColor"];
      float durationTime = [call.arguments[@"time"] floatValue];
      BOOL isFullWidth = [call.arguments[@"isFullWidth"] isEqualToString:@"true"] ? true : false;
      CSToastStyle *toast = [[CSToastStyle alloc] initWithDefaultStyle];
      toast.backgroundColor = [self colorFromHexString:bgColor];
      toast.messageAlignment = NSTextAlignmentCenter;
      toast.titleAlignment = NSTextAlignmentCenter;
      toast.titleColor = [self colorFromHexString:titleColor];
      id defaultPosition = CSToastPositionBottom;
      if ([gravity isEqualToString:@"top"]) {
          defaultPosition = CSToastPositionTop;
      } else if ([gravity isEqualToString:@"center"]) {
          defaultPosition = CSToastPositionCenter;
      }
      toast.isFullWidth = isFullWidth;
      [[UIApplication sharedApplication].keyWindow makeToast:msg duration:durationTime position:defaultPosition style:toast];
  } else {
    result(FlutterMethodNotImplemented);
  }
}

- (UIColor *)colorFromHexString:(NSString *)hexString {
    unsigned rgbValue = 0;
    NSScanner *scanner = [NSScanner scannerWithString:hexString];
    [scanner setScanLocation:1]; // bypass '#' character
    [scanner scanHexInt:&rgbValue];
    return [UIColor colorWithRed:((rgbValue & 0xFF0000) >> 16)/255.0 green:((rgbValue & 0xFF00) >> 8)/255.0 blue:(rgbValue & 0xFF)/255.0 alpha:1.0];
}

@end
